
Installation
============

Just the usual for a Python package:

.. code-block:: sh

   pip install WuttaMess

Note that this will also install these dependencies:

* `fabric <https://pypi.org/project/fabric/>`_
* `fabsync <https://pypi.org/project/fabsync/>`_
